@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import warnings
 
+from django.conf import settings
 from django.utils import importlib
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
@@ -12,7 +13,7 @@ from django.db.models import (\
     AutoField, IntegerField, SmallIntegerField,
     PositiveIntegerField, PositiveSmallIntegerField,
     BooleanField, DecimalField, FloatField,
-    FileField, ImageField,
+    FileField, ImageField, Field,
     ForeignKey, ManyToManyField, OneToOneField)
 
 try:
@@ -23,6 +24,28 @@ except ImportError:
 import generators
 from exceptions import ModelNotFound, AmbiguousModelName, InvalidQuantityException
 
+from six import string_types
+
+
+class Sequence(object):
+
+    def __init__(self, value, increment_by=1):
+        self.value = value
+        self.counter = increment_by
+        self.increment_by = increment_by
+
+    def get_inc(self, model):
+        if not model.objects.count():
+            self.counter = self.increment_by
+        i = self.counter
+        self.counter += self.increment_by
+        return i
+
+    def gen(self, model):
+        inc = self.get_inc(model)
+        return self.value + type(self.value)(inc)
+
+
 recipes = None
 
 # FIXME: use pkg_resource
@@ -70,8 +93,7 @@ def prepare(model, _quantity=None, **attrs):
 
 
 def _recipe(name):
-    splited_name = name.split('.')
-    app, recipe_name = '.'.join(splited_name[0:-1]), splited_name[-1]
+    app, recipe_name = name.rsplit('.', 1)
     recipes = importlib.import_module('.'.join([app, 'mommy_recipes']))
     return getattr(recipes, recipe_name)
 
@@ -197,13 +219,22 @@ class Mommy(object):
     def __init__(self, model, make_m2m=False):
         self.make_m2m = make_m2m
         self.m2m_dict = {}
-        self.type_mapping = default_mapping.copy()
 
         if isinstance(model, ModelBase):
             self.model = model
         else:
             self.model = self.finder.get_model(model)
 
+        self.init_type_mapping()
+
+    def init_type_mapping(self):
+        self.type_mapping = default_mapping.copy()
+        generator_from_settings = getattr(settings, 'MOMMY_CUSTOM_FIELDS_GEN', {})
+        for k, v in generator_from_settings.items():
+            path, field_name = k.rsplit('.', 1)
+            field_class = getattr(importlib.import_module(path), field_name)
+            self.type_mapping[field_class] = v
+
     def make(self, **attrs):
         '''Creates and persists an instance of the model
         associated with Mommy instance.'''
@@ -219,10 +250,10 @@ class Mommy(object):
         return self.model._meta.fields + self.model._meta.many_to_many
 
     def _make(self, commit=True, **attrs):
-        is_fk_field = lambda x: '__' in x
-        model_attrs = dict((k, v) for k, v in attrs.items() if not is_fk_field(k))
-        fk_attrs = dict((k, v) for k, v in attrs.items() if is_fk_field(k))
-        fk_fields = [x.split('__')[0] for x in fk_attrs.keys() if is_fk_field(x)]
+        is_rel_field = lambda x: '__' in x
+        model_attrs = dict((k, v) for k, v in attrs.items() if not is_rel_field(k))
+        self.rel_attrs = dict((k, v) for k, v in attrs.items() if is_rel_field(k))
+        self.rel_fields = [x.split('__')[0] for x in self.rel_attrs.keys() if is_rel_field(x)]
 
         for field in self.get_fields():
             field_value_not_defined = field.name not in model_attrs
@@ -230,12 +261,9 @@ class Mommy(object):
             if isinstance(field, (AutoField, generic.GenericRelation)):
                 continue
 
-            if isinstance(field, ForeignKey) and field.name in fk_fields:
-                model_attrs[field.name] = self.generate_value(field, **fk_attrs)
-                continue
-
-            if not field.name in self.attr_mapping and (field.has_default() or field.blank):
-                continue
+            if all([field.name not in model_attrs, field.name not in self.rel_fields, field.name not in self.attr_mapping]):
+                if not issubclass(field.__class__, Field) or field.has_default() or field.blank:
+                    continue
 
             if isinstance(field, ManyToManyField):
                 if field.name not in model_attrs:
@@ -243,15 +271,17 @@ class Mommy(object):
                 else:
                     self.m2m_dict[field.name] = model_attrs.pop(field.name)
             elif field_value_not_defined:
-                if field.null:
+                if field.name not in self.rel_fields and field.null:
                     continue
                 else:
                     model_attrs[field.name] = self.generate_value(field)
+            elif isinstance(model_attrs[field.name], Sequence):
+                model_attrs[field.name] = model_attrs[field.name].gen(self.model)
 
         return self.instance(model_attrs, _commit=commit)
 
     def m2m_value(self, field):
-        if not self.make_m2m or field.null:
+        if not (self.make_m2m or field.null) and field.name not in self.rel_fields:
             return []
         else:
             return self.generate_value(field)
@@ -286,8 +316,7 @@ class Mommy(object):
                 base_kwargs[value_key] = model_instance
                 make(through_model, **base_kwargs)
 
-
-    def generate_value(self, field, **fk_attrs):
+    def generate_value(self, field):
         '''
         Calls the generator associated with a field passing all required args.
 
@@ -316,8 +345,8 @@ class Mommy(object):
         # generating the value.
         generator_attrs = get_required_values(generator, field)
 
-        if isinstance(field, ForeignKey):
-            generator_attrs.update(filter_fk_attrs(field.name, **fk_attrs))
+        if field.name in self.rel_fields:
+            generator_attrs.update(filter_rel_attrs(field.name, **self.rel_attrs))
 
         return generator(**generator_attrs)
 
@@ -338,7 +367,7 @@ def get_required_values(generator, field):
                 key, value = item(field)
                 rt[key] = value
 
-            elif isinstance(item, basestring):
+            elif isinstance(item, string_types):
                 rt[item] = getattr(field, item)
 
             else:
@@ -347,10 +376,10 @@ def get_required_values(generator, field):
 
     return rt
 
-def filter_fk_attrs(field_name, **fk_attrs):
+def filter_rel_attrs(field_name, **rel_attrs):
     clean_dict = {}
 
-    for k, v in fk_attrs.items():
+    for k, v in rel_attrs.items():
         if k.startswith(field_name + '__'):
             splited_key = k.split('__')
             key = '__'.join(splited_key[1:])
